@@ -150,7 +150,10 @@ func (x *BwTimetable) Set(s string) error {
 		return nil
 	}
 
-	for _, tok := range strings.Split(s, " ") {
+	// Split the timetable string by both spaces and semicolons
+	for _, tok := range strings.FieldsFunc(s, func(r rune) bool {
+		return r == ' ' || r == ';'
+	}) {
 		tv := strings.Split(tok, ",")
 
 		// Format must be dayOfWeek-HH:MM,BW
@@ -165,7 +168,7 @@ func (x *BwTimetable) Set(s string) error {
 			if err := validateHour(HHMM); err != nil {
 				return err
 			}
-			for i := 0; i < 7; i++ {
+			for i := range 7 {
 				hh, _ := strconv.Atoi(HHMM[0:2])
 				mm, _ := strconv.Atoi(HHMM[3:])
 				ts := BwTimeSlot{
@@ -208,7 +211,7 @@ func (x *BwTimetable) Set(s string) error {
 	return nil
 }
 
-//	Difference in minutes between lateDayOfWeekHHMM and earlyDayOfWeekHHMM
+// Difference in minutes between lateDayOfWeekHHMM and earlyDayOfWeekHHMM
 func timeDiff(lateDayOfWeekHHMM int, earlyDayOfWeekHHMM int) int {
 
 	lateTimeMinutes := (lateDayOfWeekHHMM / 10000) * 24 * 60
