@@ -6,6 +6,7 @@ import (
 	"runtime"
 	"strings"
 	"sync"
+	"time"
 
 	"github.com/rclone/rclone/fs"
 	"github.com/rclone/rclone/fs/filter"
@@ -25,8 +26,8 @@ func createOnFirstUse() {
 	once.Do(func() {
 		ci := fs.GetConfig(context.Background())
 		c = cache.New()
-		c.SetExpireDuration(ci.FsCacheExpireDuration)
-		c.SetExpireInterval(ci.FsCacheExpireInterval)
+		c.SetExpireDuration(time.Duration(ci.FsCacheExpireDuration))
+		c.SetExpireInterval(time.Duration(ci.FsCacheExpireInterval))
 		c.SetFinalizer(func(value any) {
 			if s, ok := value.(fs.Shutdowner); ok {
 				_ = fs.CountError(context.Background(), s.Shutdown(context.Background()))
