@@ -33,7 +33,7 @@ var commandList = []commands{
 	{command: "--name-transform suffix_keep_extension=XXXX", description: "Appends XXXX to the file name while preserving the original file extension."},
 	{command: "--name-transform trimprefix=XXXX", description: "Removes XXXX if it appears at the start of the file name."},
 	{command: "--name-transform trimsuffix=XXXX", description: "Removes XXXX if it appears at the end of the file name."},
-	{command: "--name-transform regex=/pattern/replacement/", description: "Applies a regex-based transformation."},
+	{command: "--name-transform regex=pattern/replacement", description: "Applies a regex-based transformation."},
 	{command: "--name-transform replace=old:new", description: "Replaces occurrences of old with new in the file name."},
 	{command: "--name-transform date={YYYYMMDD}", description: "Appends or prefixes the specified date format."},
 	{command: "--name-transform truncate=N", description: "Truncates the file name to a maximum of N characters."},
@@ -95,10 +95,10 @@ func (e example) output() string {
 
 // go run ./ convmv --help
 func sprintExamples() string {
-	s := "Examples: \n\n"
+	s := "Examples:\n"
 	for _, e := range examples {
-		s += fmt.Sprintf("```\n%s\n", e.command())
-		s += fmt.Sprintf("// Output: %s\n```\n\n", e.output())
+		s += fmt.Sprintf("\n```sh\n%s\n", e.command())
+		s += fmt.Sprintf("// Output: %s\n```\n", e.output())
 	}
 	return s
 }
@@ -109,7 +109,7 @@ func commandTable() string {
 	for _, c := range commandList {
 		s += fmt.Sprintf("\n| `%s` | %s |", c.command, c.description)
 	}
-	s += "\n\n"
+	s += "\n"
 	return s
 }
 
@@ -119,19 +119,19 @@ func SprintList() string {
 	var charmaps transform.CharmapChoices
 
 	s := commandTable()
-	s += "Conversion modes:\n\n```\n"
+	s += "\nConversion modes:\n\n```text\n"
 	for _, v := range algos.Choices() {
 		s += v + "\n"
 	}
 	s += "```\n\n"
 
-	s += "Char maps:\n\n```\n"
+	s += "Char maps:\n\n```text\n"
 	for _, v := range charmaps.Choices() {
 		s += v + "\n"
 	}
 	s += "```\n\n"
 
-	s += "Encoding masks:\n\n```\n"
+	s += "Encoding masks:\n\n```text\n"
 	for _, v := range strings.Split(encoder.ValidStrings(), ", ") {
 		s += v + "\n"
 	}
@@ -154,5 +154,5 @@ func main() {
 		defer out.Close()
 	}
 	fmt.Fprintf(out, "<!--- Docs generated by help.go - use go generate to rebuild - DO NOT EDIT --->\n\n")
-	fmt.Fprintln(out, SprintList())
+	fmt.Fprint(out, SprintList())
 }
